==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NumericXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StraightNumericAxisBaseDescriptionMetadata } from "./StraightNumericAxisBaseDescriptionMetadata";
import { NumericXAxisDescription } from "./NumericXAxisDescription";
/**
 * @hidden
 */
var NumericXAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericXAxisDescriptionMetadata, _super);
    function NumericXAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericXAxisDescriptionMetadata.b = function (a) {
        if (NumericXAxisDescriptionMetadata.a == null) {
            NumericXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericXAxisDescriptionMetadata.c(NumericXAxisDescriptionMetadata.a);
        }
        if (a.g(NumericXAxisDescriptionMetadata.a)) {
            return;
        }
        a.s(NumericXAxisDescriptionMetadata.a);
    };
    NumericXAxisDescriptionMetadata.c = function (a) {
        StraightNumericAxisBaseDescriptionMetadata.c(a);
    };
    NumericXAxisDescriptionMetadata.d = function (a) {
        NumericXAxisDescriptionMetadata.b(a);
        a.u("NumericXAxis", function () { return new NumericXAxisDescription(); });
        a.t("NumericXAxis", NumericXAxisDescriptionMetadata.a);
    };
    NumericXAxisDescriptionMetadata.$t = markType(NumericXAxisDescriptionMetadata, 'NumericXAxisDescriptionMetadata');
    NumericXAxisDescriptionMetadata.a = null;
    return NumericXAxisDescriptionMetadata;
}(Base));
export { NumericXAxisDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NumericXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StraightNumericAxisBaseDescriptionMetadata } from "./StraightNumericAxisBaseDescriptionMetadata";
import { NumericXAxisDescription } from "./NumericXAxisDescription";
/**
 * @hidden
 */
var NumericXAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericXAxisDescriptionMetadata, _super);
    function NumericXAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericXAxisDescriptionMetadata.b = function (a) {
        if (NumericXAxisDescriptionMetadata.a == null) {
            NumericXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericXAxisDescriptionMetadata.c(NumericXAxisDescriptionMetadata.a);
        }
        if (a.j(NumericXAxisDescriptionMetadata.a)) {
            return;
        }
        a.y(NumericXAxisDescriptionMetadata.a);
    };
    NumericXAxisDescriptionMetadata.c = function (a) {
        StraightNumericAxisBaseDescriptionMetadata.c(a);
    };
    NumericXAxisDescriptionMetadata.d = function (a) {
        NumericXAxisDescriptionMetadata.b(a);
        a.aa("NumericXAxis", function () { return new NumericXAxisDescription(); });
        a.z("NumericXAxis", NumericXAxisDescriptionMetadata.a);
    };
    NumericXAxisDescriptionMetadata.$t = markType(NumericXAxisDescriptionMetadata, 'NumericXAxisDescriptionMetadata');
    NumericXAxisDescriptionMetadata.a = null;
    return NumericXAxisDescriptionMetadata;
}(Base));
export { NumericXAxisDescriptionMetadata };
